libname out "c:\ethanol\feb05\renorm\aicc";
libname feb "c:\ethanol\feb05\renorm";

OPTIONS LS=79 ps=59;


proc datasets library=out;
delete icall12;
run;


/* MACRO to run mixed model variants */
/* In all these cases, fixed and random interaction terms are the same (no weights)
so we don't need to have fterms and rterms in macro calls  */

%macro runmix(data, method, code, fterms, extra);


PROC MIXED DATA=&data MAXITER=500 METHOD=&method NOCLPRINT ic ;
CLASS NEW;
TITLE "Code &code : NOx model using &data with method &method and terms &fterms";

MODEL LN_NOX = RV T5 T9 AR OL OX SU SUOX T5OX T5T5 RVT9 RVOL T5OL ARAR OXOX ARSU T9AR OLOL
               &fterms
               /S DDFM=RES;

RANDOM         int RV T5 T9 AR OL OX SU SUOX T5OX T5T5 RVT9 RVOL T5OL ARAR OXOX ARSU T9AR OLOL
              &fterms
               /SUB=NEW;
ods output infocrit=ic;
run;

data icall;
set ic;
length modcode $ 5;
modcode="&code";
 run;

proc append base=out.icall12 data=icall;
run;


%mend runmix;


%macro main;

    %runmix(feb.icfall, ml, 0, , );
    %runmix(feb.icfall, ml, 12a, rvar, rvar);
*    %runmix(feb.icfall, ml, 12b, rvol, rvol);
    %runmix(feb.icfall, ml, 12c, rvox, rvox);
    %runmix(feb.icfall, ml, 12d, rvrv, rvrv);
    %runmix(feb.icfall, ml, 12e, rvsu, rvsu);
    %runmix(feb.icfall, ml, 12f, rvt5, rvt5);
*    %runmix(feb.icfall, ml, 12g, rvt9, rvt9);
    %runmix(feb.icfall, ml, 12h, t5ar, t5ar);
*    %runmix(feb.icfall, ml, 12i, t5ol, t5ol);
*    %runmix(feb.icfall, ml, 12j, t5ox, t5ox);
    %runmix(feb.icfall, ml, 12k, t5su, t5su);
*    %runmix(feb.icfall, ml, 12l, t5t5, t5t5);
    %runmix(feb.icfall, ml, 12m, t5t9, t5t9);
*    %runmix(feb.icfall, ml, 12n, t9ar, t9ar);
    %runmix(feb.icfall, ml, 12o, t9ol, t9ol);
    %runmix(feb.icfall, ml, 12p, t9ox, t9ox);
    %runmix(feb.icfall, ml, 12q, t9su, t9su);
    %runmix(feb.icfall, ml, 12r, t9t9, t9t9);
*    %runmix(feb.icfall, ml, 12s, arar, arar);
    %runmix(feb.icfall, ml, 12t, arol, arol);
    %runmix(feb.icfall, ml, 12u, arox, arox);
*    %runmix(feb.icfall, ml, 12v, arsu, arsu);
*    %runmix(feb.icfall, ml, 12w, olol, olol);
    %runmix(feb.icfall, ml, 12x, olox, olox);
    %runmix(feb.icfall, ml, 12y, olsu, olsu);
*    %runmix(feb.icfall, ml, 12z, suox, suox);
    %runmix(feb.icfall, ml, 12*, susu, susu);
*    %runmix(feb.icfall, ml, 12+, oxox, oxox);


proc means data=out.icall12 noprint;
var aicc;
output out=minic minid(aicc (aicc modcode))=minaicc mincode;
run;

proc print data=minic;
run;

%mend main;

%main
