libname out "c:\ethanol\feb05\renorm\aicc";
libname feb "c:\ethanol\feb05\renorm";

OPTIONS LS=79 ps=59;


proc datasets library=out;
delete icall6;
run;


/* MACRO to run mixed model variants */
/* In all these cases, fixed and random interaction terms are the same (no weights)
so we don't need to have fterms and rterms in macro calls  */

%macro runmix(data, method, code, fterms, extra);


PROC MIXED DATA=&data MAXITER=500 METHOD=&method NOCLPRINT ic ;
CLASS NEW;
TITLE "Code &code : NOx model using &data with method &method and terms &fterms";

MODEL LN_NOX = RV T5 T9 AR OL OX SU SUOX T5OX T5T5 RVT9 RVOL
               &fterms
               /S DDFM=RES;

RANDOM         int RV T5 T9 AR OL OX SU SUOX T5OX T5T5 RVT9 RVOL
               &fterms
               /SUB=NEW;
ods output infocrit=ic;
run;

data icall;
set ic;
length modcode $ 5;
modcode="&code";
run;

proc append base=out.icall6 data=icall;
run;


%mend runmix;


%macro main;

    %runmix(feb.icfall, ml, 0, , );
    %runmix(feb.icfall, ml, 6a, rvar, rvar);
*    %runmix(feb.icfall, ml, 6b, rvol, rvol);
    %runmix(feb.icfall, ml, 6c, rvox, rvox);
    %runmix(feb.icfall, ml, 6d, rvrv, rvrv);
    %runmix(feb.icfall, ml, 6e, rvsu, rvsu);
    %runmix(feb.icfall, ml, 6f, rvt5, rvt5);
*    %runmix(feb.icfall, ml, 6g, rvt9, rvt9);
    %runmix(feb.icfall, ml, 6h, t5ar, t5ar);
    %runmix(feb.icfall, ml, 6i, t5ol, t5ol);
*    %runmix(feb.icfall, ml, 6j, t5ox, t5ox);
    %runmix(feb.icfall, ml, 6k, t5su, t5su);
*    %runmix(feb.icfall, ml, 6l, t5t5, t5t5);
    %runmix(feb.icfall, ml, 6m, t5t9, t5t9);
    %runmix(feb.icfall, ml, 6n, t9ar, t9ar);
    %runmix(feb.icfall, ml, 6o, t9ol, t9ol);
    %runmix(feb.icfall, ml, 6p, t9ox, t9ox);
    %runmix(feb.icfall, ml, 6q, t9su, t9su);
    %runmix(feb.icfall, ml, 6r, t9t9, t9t9);
    %runmix(feb.icfall, ml, 6s, arar, arar);
    %runmix(feb.icfall, ml, 6t, arol, arol);
    %runmix(feb.icfall, ml, 6u, arox, arox);
    %runmix(feb.icfall, ml, 6v, arsu, arsu);
    %runmix(feb.icfall, ml, 6w, olol, olol);
    %runmix(feb.icfall, ml, 6x, olox, olox);
    %runmix(feb.icfall, ml, 6y, olsu, olsu);
*    %runmix(feb.icfall, ml, 6z, suox, suox);
    %runmix(feb.icfall, ml, 6*, susu, susu);
    %runmix(feb.icfall, ml, 6+, oxox, oxox);


proc means data=out.icall6 noprint;
var aicc;
output out=minic minid(aicc (aicc modcode))=minaicc mincode;
run;

proc print data=minic;
run;

%mend main;

%main
